@@ -43,7 +43,7 @@ oceNames2whpNames <- function(names)
     names <- gsub("nitrite", "NITRIT", names)
     names <- gsub("number", "NUMBER", names)
     names <- gsub("nitrite+nitrate", "NO2+NO3", names)
-    names <- gsub("oxygen", "OXYGEN", names)
+    names <- gsub("oxygenBottle", "OXYGEN", names)
     names <- gsub("quality", "QUALT", names) # flags, really, but we are not capturing that info yet
     names <- gsub("salinityBottle", "SALNTY", names)
     names <- gsub("SF6", "SF6", names)
@@ -182,7 +182,7 @@ woceNames2oceNames <- function(names)
     names <- gsub("NITRIT", "nitrite", names)
     names <- gsub("NUMBER", "number", names)
     names <- gsub("NO2+NO3", "nitrite+nitrate", names)
-    names <- gsub("OXYGEN", "oxygen", names)
+    names <- gsub("OXYGEN", "oxygenBottle", names)
     names <- gsub("QUALT", "quality", names) # flags, really, but we are not capturing that info yet
     names <- gsub("SALNTY", "salinityBottle", names)
     names <- gsub("SF6", "SF6", names)
