@@ -1,3 +1,5 @@
+# vim:textwidth=80:expandtab:shiftwidth=4:softtabstop=4
+
 #' Solar Angle as Function of Space and Time
 #'
 #' This calculates solar angle, based on a NASA-provided Fortran
@@ -6,7 +8,9 @@
 #'
 #' @param t time, a POSIXt object (converted to timezone `"UTC"`,
 #' if it is not already in that timezone), a character or numeric value that
-#' corresponds to such a time.
+#' corresponds to such a time.  This may be a single value or a vector
+#' of values.  In the latter case, `longitude`, `latitude` and `useRefraction`
+#' are all made to be of the same length as `time`, by calling [rep()].
 #'
 #' @param longitude observer longitude in degrees east.
 #'
@@ -64,58 +68,65 @@
 #'     sunAngle(rise, lonlat[1], lonlat[2])$altitude^2 + sunAngle(set, lonlat[1], lonlat[2])$altitude^2
 #' }
 #' result <- optim(c(1,1), mismatch)
-#' lon.hfx <- (-63.55274)
-#' lat.hfx <- 44.65
-#' dist <- geodDist(result$par[1], result$par[2], lon.hfx, lat.hfx)
+#' lonHfx <- (-63.55274)
+#' latHfx <- 44.65
+#' dist <- geodDist(result$par[1], result$par[2], lonHfx, latHfx)
 #' cat(sprintf("Infer Halifax latitude %.2f and longitude %.2f; distance mismatch %.0f km",
 #'             result$par[2], result$par[1], dist))
 #'
 #' @family things related to astronomy
 #'
 #' @author Dan Kelley
-sunAngle <- function(t, longitude=0, latitude=0, useRefraction=FALSE)
+sunAngle <- function(t, longitude=0.0, latitude=0.0, useRefraction=FALSE)
 {
-    if (missing(t)) stop("must provide t")
-    if (is.character(t))
-        t <- as.POSIXct(t, tz="UTC")
-    else if (inherits(t, "Date"))
-        t <- as.POSIXct(t)
-    if (!inherits(t, "POSIXt")) {
-        if (is.numeric(t)) {
-            tref <- as.POSIXct("2000-01-01 00:00:00", tz="UTC") # arbitrary
-            t <- t - as.numeric(tref) + tref
-        } else {
-            stop("t must be POSIXt or a number corresponding to POSIXt (in UTC)")
+    if (missing(t)) {
+        stop("must provide t")
+    } else {
+        if (is.character(t))
+            t <- as.POSIXct(t, tz="UTC")
+        if (inherits(t, "Date"))
+            t <- as.POSIXct(t)
+        if (!inherits(t, "POSIXt")) {
+            if (is.numeric(t)) {
+                tref <- as.POSIXct("2000-01-01 00:00:00", tz="UTC") # arbitrary
+                t <- t - as.numeric(tref) + tref
+            } else {
+                stop("t must be POSIXt or a number corresponding to POSIXt (in UTC)")
+            }
         }
     }
     t <- as.POSIXct(t) # so we can get length ... FIXME: silly, I know
-    ## Ensure that the timezone is UTC. Note that Sys.Date() gives a NULL tzone.
+    nt <- length(t)
+    nlongitude <- length(longitude)
+    nlatitude <- length(latitude)
+    nuseRefraction <- length(useRefraction)
+    if (nlongitude != nlatitude) {
+        stop("lengths of longitude and latitude must match")
+    }
+    if (nlongitude != nuseRefraction) {
+        stop("lengths of longitude and useRefraction must match")
+    }
+    if (nlongitude == 1) {
+        longitude <- rep(longitude, length.out=nt)
+        latitude <- rep(latitude, length.out=nt)
+        useRefraction <- rep(useRefraction, length.out=nt)
+    } else {
+        stop("lengths of longitude, latitude and useRefraction must be 1 or the length of time")
+    }
+    # Ensure that the timezone is UTC. Note that Sys.Date() gives a NULL tzone.
     tzone <- attr(as.POSIXct(t[1]), "tzone")
     if (is.null(tzone) || "UTC" != tzone)
         attributes(t)$tzone <- "UTC"
-    tOrig <- t
-    ok <- !is.na(t)
-    ntOrig <- length(t)
-    nt <- sum(ok)
-    t <- t[ok]
-    t <- as.POSIXlt(t) # so we can get yday etc ... FIXME: silly, I know
-    nlon <- length(longitude)
-    nlat <- length(latitude)
-    if (nlon != nlat) stop("lengths of longitude and latitude must match")
-    if (nlon == 1) {
-        longitude <- rep(longitude, nt) # often, give a time vector but just one location
-        latitude <- rep(latitude, nt)
-    } else {
-        if (ntOrig != nlon) stop("lengths of t, latitude and longitude must match, unless last two are of length 1")
+    ok <- is.finite(t)
+    if (!all(ok)) {
+        warning("removing ", sum(!ok), " data, for which time is not finite")
+        t <- t[ok]
+        latitude <- latitude[ok]
+        longitude <- longitude[ok]
+        useRefraction <- useRefraction[ok]
     }
-    ## need vectors to handle NA
-    azOut <- rep(NA, length.out=ntOrig)
-    elOut <- rep(NA, length.out=ntOrig)
-    soldiaOut <- rep(NA, length.out=ntOrig)
-    soldstOut <- rep(NA, length.out=ntOrig)
-
-    ## the code below is derived from fortran code, downloaded 2009-11-1 from
-    ## ftp://climate1.gsfc.nasa.gov/wiscombe/Solar_Rad/SunAngles/sunae.f
+    # the code below is derived from fortran code, downloaded 2009-11-1 from
+    # ftp://climate1.gsfc.nasa.gov/wiscombe/Solar_Rad/SunAngles/sunae.f
     t <- as.POSIXlt(t)                 # use this so we can work on hours, etc
     if ("UTC" != attr(as.POSIXct(t[1]), "tzone"))
         stop("t must be in UTC")
@@ -144,10 +155,9 @@ sunAngle <- function(t, longitude=0, latitude=0, useRefraction=FALSE)
         warning("longitude(s) trimmed to range -180 to 180")
         longitude[longitude >  180] <-  180
     }
-
     delta <- year - 1949
     leap <- delta %/% 4
-    ## FIXME: using fortran-style int and mod here; must check for leap-year cases
+    # IXME: using fortran-style int and mod here; must check for leap-year cases
     jd <- 32916.5 + (delta * 365 + leap + day) + hour / 24
     jd <- jd + ifelse(0 == (year %% 100) & 0 != (year %% 400), 1, 0)
     time <- jd - 51545
@@ -161,7 +171,7 @@ sunAngle <- function(t, longitude=0, latitude=0, useRefraction=FALSE)
     mnanom <- mnanom * rpd
     eclong <- mnlong + 1.915*sin(mnanom) + 0.020*sin(2 * mnanom)
     eclong <- eclong %% 360
-    eclong <- eclong + ifelse (eclong < 0, 360, 0)
+    eclong <- eclong + ifelse(eclong < 0, 360, 0)
     oblqec <- 23.439 - 0.0000004 * time
     eclong <- eclong * rpd
     oblqec <- oblqec * rpd
@@ -178,40 +188,31 @@ sunAngle <- function(t, longitude=0, latitude=0, useRefraction=FALSE)
     lmst <- lmst + ifelse(lmst < 0, 24, 0)
     lmst <- lmst * 15 * rpd
     ha <- lmst - ra
-    ha <- ha + ifelse (ha < (-pi), 2 * pi, 0)
-    ha <- ha - ifelse (ha > pi, 2 * pi, 0)
+    ha <- ha + ifelse(ha < (-pi), 2 * pi, 0)
+    ha <- ha - ifelse(ha > pi, 2 * pi, 0)
     el <- asin(sin(dec) * sin(latitude * rpd) + cos(dec) * cos(latitude*rpd)*cos(ha))
-    ## pin the arg to range -1 to 1 (issue 1004)
+    # pin the arg to range -1 to 1 (issue 1004)
     sinAz <- -cos(dec) * sin(ha) / cos(el)
     az <- ifelse(sinAz < (-1), -pi/2,
-                 ifelse(sinAz > 1, pi/2,
-                        asin(sinAz)))
-    az <-  ifelse(sin(dec) - sin(el) * sin(latitude * rpd ) > 0,
-                  ifelse (sin(az) < 0, az + 2 * pi, az),
-                  pi - az)
+        ifelse(sinAz > 1, pi/2,
+            asin(sinAz)))
+    az <-  ifelse(sin(dec) - sin(el) * sin(latitude * rpd) > 0,
+        ifelse(sin(az) < 0, az + 2 * pi, az),
+        pi - az)
     el <- el / rpd
     az <- az / rpd
-    if (useRefraction) {
-        refrac <- ifelse(el >= 19.225,
-                         0.00452 * 3.51823 / tan(el * rpd),
-                         ifelse (el > (-0.766) & el < 19.225,
-                                 3.51823 * (0.1594 + el * (0.0196 + 0.00002 * el)) / (1 + el * (0.505 + 0.0845 * el)),
-                                 0))
-        el  <- el + refrac
-    }
+    el <- el + ifelse(useRefraction,
+        ifelse(el >= 19.225,
+            0.00452 * 3.51823 / tan(el * rpd),
+            ifelse(el > (-0.766) & el < 19.225,
+                3.51823 * (0.1594 + el * (0.0196 + 0.00002 * el)) / (1 + el * (0.505 + 0.0845 * el)),
+                0)),
+        0)
     soldst <- 1.00014 - 0.01671 * cos(mnanom) - 0.00014 * cos(2 * mnanom)
     soldia <- 0.5332 / soldst
-    if (is.na(el) || any(el < (-90.0)) || any(el > 90))
-        stop("output argument el out of range")
-    if (is.na(az) || any(az < 0) || any(az > 360))
-        stop("output argument az out of range")
-    azOut[ok] <- az
-    elOut[ok] <- el
-    soldiaOut[ok] <- soldia
-    soldstOut[ok] <- soldst
-    sunDRA <- sunDeclinationRightAscension(tOrig, apparent=FALSE)
-    list(time=tOrig, azimuth=azOut, altitude=elOut, diameter=soldiaOut, distance=soldstOut,
-         declination=sunDRA$declination, rightAscension=sunDRA$rightAscension)
+    sunDRA <- sunDeclinationRightAscension(t, apparent=FALSE)
+    list(time=t, azimuth=az, altitude=el, diameter=soldia, distance=soldst,
+        declination=sunDRA$declination, rightAscension=sunDRA$rightAscension)
 }
 
 #' Sun Declination and Right Ascension
@@ -227,13 +228,13 @@ sunAngle <- function(t, longitude=0, latitude=0, useRefraction=FALSE)
 #' @return A list containing `declination` and `rightAscension`, in degrees.
 #'
 #' @examples
-#' ## Example 24.a in Meeus (1991) (page 158 PDF, 153 print)
+#' # Example 24.a in Meeus (1991) (page 158 PDF, 153 print)
 #' time <- as.POSIXct("1992-10-13 00:00:00", tz="UTC")
 #' a <- sunDeclinationRightAscension(time, apparent=TRUE)
 #' stopifnot(abs(a$declination - (-7.78507)) < 0.00004)
 #' stopifnot(abs(a$rightAscension - (-161.61919)) < 0.00003)
 #' b <- sunDeclinationRightAscension(time)
-#' ## check against previous results, to protect aginst code-drift errors
+#' # check against previous results, to protect aginst code-drift errors
 #' stopifnot(abs(b$declination - (-7.785464443)) < 0.000000001)
 #' stopifnot(abs(b$rightAscension - (-161.6183305)) < 0.0000001)
 #'
@@ -245,46 +246,47 @@ sunAngle <- function(t, longitude=0, latitude=0, useRefraction=FALSE)
 #' @author Dan Kelley, based on formulae in Meeus (1991).
 sunDeclinationRightAscension <- function(time, apparent=FALSE)
 {
-    ##<UNUSED> year <- as.numeric(format(time, "%Y"))
     k <-  2 * pi / 360                     # k*degrees == radians
-    ## Meeus 1991 pdf page 158, print page 153
+    # Meeus 1991 pdf page 158, print page 153
     JD <- julianDay(time)
+    # nolint start T_and_F_symbol_lintr
     T <- (JD - 2451545.0) / 36525          # Meeus (1991) eq (24.1)
-    ## L0 = geometric mean longitude of sun, referred to mean equinox of date
+    # L0 = geometric mean longitude of sun, referred to mean equinox of date
     L0 <- 280.46645 + 36000.76983*T + 0.0003032*T^2 # Meeus (1991) eq (24.2)
     L0 <- L0 %% 360
-    ## mean anomaly of sun
+    # mean anomaly of sun
     M <- 357.52910 + 35999.05030*T - 0.0001558*T^2 - 0.00000048*T^3
     M <- M %% 360
-    ## e = eccentricity of earth's orbit, Meeus (1991) first unnumbered eqn after (24.4)
-    ##<UNUSED> e <- 0.016708617 - 0.000042037*T - 0.0000001236*T^2
-    ## sun equation of center C
+    # e = eccentricity of earth's orbit, Meeus (1991) first unnumbered eqn after (24.4)
+    #<UNUSED> e <- 0.016708617 - 0.000042037*T - 0.0000001236*T^2
+    # sun equation of center C
     C <- (1.914600-0.004817*T-0.000014*T^2)*sin(k*M) + (0.019993-0.000101*T)*sin(k*2*M) + 0.000290*sin(3*k*M)
-    ## sun true longitude: Meeus (1991) second eqn after eqn (24.4)
+    # sun true longitude: Meeus (1991) second eqn after eqn (24.4)
     Theta <- L0 + C
-    ## sun true anomaly
-    ##<UNUSED> nu <- M + C
-    ##> sun radius vector (dist earth to sun, in AU)
-    ##<UNUSED> R <- (1.000001018 * (1 - e^2)) / (1 + e * cos(k * nu))
-    ## first unnumbered eqn after Meeus (1991) eqn (24.5)
+    # sun true anomaly
+    #<UNUSED> nu <- M + C
+    #> sun radius vector (dist earth to sun, in AU)
+    #<UNUSED> R <- (1.000001018 * (1 - e^2)) / (1 + e * cos(k * nu))
+    # first unnumbered eqn after Meeus (1991) eqn (24.5)
     Omega <- 125.04 - 1934.136 * T
-    ## second unnumbered eqn after Meeus (1991) eqn (24.5)
+    # second unnumbered eqn after Meeus (1991) eqn (24.5)
     lambda <- Theta - 0.00569 - 0.00478 * sin(k*Omega)
-    ##<UNUSED> Theta2000 <- Theta - 0.01397 * (year - 2000)
-    ## epsilon: Meeus (1991) eqn (21.1) (PDF page 140, print page 135)
-    ## mean obliquity of ecliptic
+    #<UNUSED> Theta2000 <- Theta - 0.01397 * (year - 2000)
+    # epsilon: Meeus (1991) eqn (21.1) (PDF page 140, print page 135)
+    # mean obliquity of ecliptic
     epsilon0 <- 23+(26+21.448/60)/60 - 46.8150/60^2*T - 0.00059/60^2*T^2 + 0.001813/60^2*T^3
     L <- 280.4665 + 36000.7698*T           # Meeus (1991) PDF page 137, print page 132
     Lprime <- 218.3165 + 481267.8813*T     # Meeus (1991) PDF page 137, print page 132
-    ## NOT same Omega as above, but we are following the trail of equations step by step,
-    ## and the following actually passes the test above so perhaps the previous eqn for
-    ## Omega was an approximation.
-    ## Omega <- 125.04452 - 1934.136261*T + 0.0020708*T^2 + T^3/450000 # Meeus (1991) PDF page 137, print page 132
-    ## But he then says to drop the T^2 and T^3 terms before giving the DeltaEpsilon eqn, so we do that.
+    # NOT same Omega as above, but we are following the trail of equations step by step,
+    # and the following actually passes the test above so perhaps the previous eqn for
+    # Omega was an approximation.
+    # Omega <- 125.04452 - 1934.136261*T + 0.0020708*T^2 + T^3/450000 # Meeus (1991) PDF page 137, print page 132
+    # But he then says to drop the T^2 and T^3 terms before giving the DeltaEpsilon eqn, so we do that.
     Omega <- 125.04452 - 1934.136261*T # Meeus (1991) PDF page 137, print page 132
+    # nolint end T_and_F_symbol_lintr
     DeltaEpsilon <- 9.20/60^2*cos(k*Omega) + 0.57/60^2*cos(k*2*L) + 0.10/60^2*cos(k*2*Lprime) - 0.09/60^2*cos(k*2*Omega)
     epsilon <- epsilon0 + DeltaEpsilon
-    ## alpha Meeus (1991)  eqn (24.6) PDF page 158, print page 153
+    # alpha Meeus (1991)  eqn (24.6) PDF page 158, print page 153
     if (apparent) {
         epsilonA <- epsilon + 0.00256*cos(k*Omega)
         alpha <- 1/k * atan2(cos(k*epsilonA) * sin(k*lambda), cos(k*lambda))
@@ -295,4 +297,3 @@ sunDeclinationRightAscension <- function(time, apparent=FALSE)
     }
     list(declination=delta, rightAscension=alpha)
 }
-
